<?php

namespace Drupal\cds_activecampaign\Plugin\CustomerDataStorage;

use Drupal\activecampaign\ActiveCampaignApi;
use Drupal\cds\CustomerDataStoragePluginBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the customer data storage.
 *
 * @CustomerDataStorage(
 *   id = "activecampaign",
 *   weight = 0,
 *   name = @Translation("ActiveCampaign"),
 *   description = @Translation("CDS based on ActiveCampaign."),
 *   config_route_name = "cds_activecampaign.settings_form",
 * )
 */
class ActiveCampaign extends CustomerDataStoragePluginBase implements ContainerFactoryPluginInterface {
  use StringTranslationTrait;

  /**
   * The ActiveCampaign API.
   *
   * @var \Drupal\activecampaign\ActiveCampaignApi
   */
  protected $activeCampaignApi;

  /**
   * The ActiveCampaign contact ID.
   *
   * @var int
   */
  protected $contactId;

  /**
   * Constructs a ActiveCampaign object.
   *
   * @param \Drupal\activecampaign\ActiveCampaignApi $active_campaign_api
   *   The ActiveCampaignApi service.
   */
  public function __construct(ActiveCampaignApi $active_campaign_api) {
    $this->activeCampaignApi = $active_campaign_api;

    // @todo Provide a way to retrieve the contact.
    $this->contactId = 1;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $container->get('activecampaign.api')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getField(string $field): string {
    $contact = $this->activeCampaignApi->getContact($this->contactId);

    if ($contact) {
      return $contact->{$field} ?: '';
    }

    return '';
  }

  /**
   * {@inheritdoc}
   */
  public function setField(string $field, string $data) {
    // TODO: Implement setField() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getAllFields(): array {
    return [
      'email' => $this->t('E-mail'),
      'phone' => $this->t('Phone'),
      'firstName' => $this->t('First name'),
      'lastName' => $this->t('Last name'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getSegments(): array {
    // TODO: Implement getSegments() method.
  }

  /**
   * {@inheritdoc}
   */
  public function addSegment(string $segment) {
    // TODO: Implement addSegment() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getAllSegments(): array {
    // TODO: Implement getAllSegments() method.
  }

}
